/*!
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

@keyframes loadingDotBlink {
  0% {
    opacity: 0.2;
  }

  40% {
    opacity: 1;
  }

  100% {
    opacity: 0.2;
  }
}

.loading-dots {
  display: inline-block;
}

.loading-dot {
  display: inline-block;
  margin-left: 0.5rem;
  border-radius: 50%;
  width: 10px;
  height: 10px;
  background-color: currentColor;
  animation: loadingDotBlink 1.2s infinite;
  animation-fill-mode: both;
  will-change: opacity;
}

.loading-dot:first-child {
  margin-left: 0;
}

.loading-dot:nth-child(2) {
  animation-delay: 0.2s;
}

.loading-dot:nth-child(3) {
  animation-delay: 0.4s;
}
